package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Oct 1, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Abs[T num.R](x T) (abs T)
取绝对值,实数范围
func Max[T num.R](x1, x2 T) (max T)
取最大函数,实数范围
func Min[T num.R](x1, x2 T) (min T)
取最小值,实数范围
Source Files
¶
Click to show internal directories.
Click to hide internal directories.